pub struct Settings {
pub backend: Backend,
pub antialiasing: bool,
pub vsync: bool,
}Expand description
The settings usted to configure a Backend.
Fields
backend: BackendThe graphical backend to use.
It defaults to Backend::Best.
antialiasing: boolIf set to true, the renderer will try to perform antialiasing for some primitives.
Enabling it can produce a smoother result in some widgets, like the
Canvas, at a performance cost.
By default, it is true.
vsync: boolWhether or not to synchronize frames.
By default, it is true.